==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/GovernanceRuleSetting.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ruleIdentifier", 
    "setting"})
@JsonInclude(Include.NON_NULL)
public class GovernanceRuleSetting implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ruleIdentifier")
    protected String ruleIdentifier;

    @JsonProperty("setting")
    protected String setting;

    protected GovernanceRuleSetting() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.governanceRuleSetting";
    }

    @Property(name="ruleIdentifier")
    @JsonIgnore
    public Optional<String> getRuleIdentifier() {
        return Optional.ofNullable(ruleIdentifier);
    }

    public GovernanceRuleSetting withRuleIdentifier(String ruleIdentifier) {
        GovernanceRuleSetting _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.governanceRuleSetting");
        _x.ruleIdentifier = ruleIdentifier;
        return _x;
    }

    @Property(name="setting")
    @JsonIgnore
    public Optional<String> getSetting() {
        return Optional.ofNullable(setting);
    }

    public GovernanceRuleSetting withSetting(String setting) {
        GovernanceRuleSetting _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.governanceRuleSetting");
        _x.setting = setting;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String ruleIdentifier;
        private String setting;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder ruleIdentifier(String ruleIdentifier) {
            this.ruleIdentifier = ruleIdentifier;
            this.changedFields = changedFields.add("ruleIdentifier");
            return this;
        }

        public Builder setting(String setting) {
            this.setting = setting;
            this.changedFields = changedFields.add("setting");
            return this;
        }

        public GovernanceRuleSetting build() {
            GovernanceRuleSetting _x = new GovernanceRuleSetting();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.governanceRuleSetting";
            _x.ruleIdentifier = ruleIdentifier;
            _x.setting = setting;
            return _x;
        }
    }

    private GovernanceRuleSetting _copy() {
        GovernanceRuleSetting _x = new GovernanceRuleSetting();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.ruleIdentifier = ruleIdentifier;
        _x.setting = setting;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("GovernanceRuleSetting[");
        b.append("ruleIdentifier=");
        b.append(this.ruleIdentifier);
        b.append(", ");
        b.append("setting=");
        b.append(this.setting);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/GovernanceRuleSetting.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ruleIdentifier", 
    "setting"})
@JsonInclude(Include.NON_NULL)
public class GovernanceRuleSetting implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ruleIdentifier")
    protected String ruleIdentifier;

    @JsonProperty("setting")
    protected String setting;

    protected GovernanceRuleSetting() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.governanceRuleSetting";
    }

    @Property(name="ruleIdentifier")
    @JsonIgnore
    public Optional<String> getRuleIdentifier() {
        return Optional.ofNullable(ruleIdentifier);
    }

    public GovernanceRuleSetting withRuleIdentifier(String ruleIdentifier) {
        GovernanceRuleSetting _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.governanceRuleSetting");
        _x.ruleIdentifier = ruleIdentifier;
        return _x;
    }

    @Property(name="setting")
    @JsonIgnore
    public Optional<String> getSetting() {
        return Optional.ofNullable(setting);
    }

    public GovernanceRuleSetting withSetting(String setting) {
        GovernanceRuleSetting _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.governanceRuleSetting");
        _x.setting = setting;
        return _x;
    }

    public GovernanceRuleSetting withUnmappedField(String name, Object value) {
        GovernanceRuleSetting _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String ruleIdentifier;
        private String setting;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder ruleIdentifier(String ruleIdentifier) {
            this.ruleIdentifier = ruleIdentifier;
            this.changedFields = changedFields.add("ruleIdentifier");
            return this;
        }

        public Builder setting(String setting) {
            this.setting = setting;
            this.changedFields = changedFields.add("setting");
            return this;
        }

        public GovernanceRuleSetting build() {
            GovernanceRuleSetting _x = new GovernanceRuleSetting();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.governanceRuleSetting";
            _x.ruleIdentifier = ruleIdentifier;
            _x.setting = setting;
            return _x;
        }
    }

    private GovernanceRuleSetting _copy() {
        GovernanceRuleSetting _x = new GovernanceRuleSetting();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.ruleIdentifier = ruleIdentifier;
        _x.setting = setting;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("GovernanceRuleSetting[");
        b.append("ruleIdentifier=");
        b.append(this.ruleIdentifier);
        b.append(", ");
        b.append("setting=");
        b.append(this.setting);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
